using System;
using Gtk;
using GConf;
using System.IO;
using Mono.Unix;
using Banshee.Base;
using Banshee.Gui;
using Banshee.Widgets;
using Banshee.Sources;
using Banshee.MediaEngine;
using System.Threading;
using System.Diagnostics;
public static class PluginModuleEntry
{
    public static Type [] GetTypes()
    {
        return new Type [] {
                   typeof(Banshee.Plugin.SendTo.SendToPlugin)
               };
    }
}
namespace Banshee.Plugin.SendTo
{
public class SendToPlugin : Banshee.Plugins.Plugin
{
	private bool enabled = true;		
	private TreeView current_playlist;
	private uint ui_manager_id;		
    /* Begin Plugin overrides */
    protected override string ConfigurationName { get { return "SendTo"; }
                                                }
    public override string DisplayName { get { return "SendTo"; }
                                       }

    public override string Description {
        get {
            return Catalog.GetString(
                       "A Banshee plugin that integrate " +
                       "banshee with nautilus sendto"
                   );
        }
    }

    public override string [] Authors {
        get {
            return new string [] {
                       "Christian Martellini <martellc@cs.unibo.it>"
                   };
        }
    }
    /* End Plugin overrides */
    
    /* Begin plugin initialization */
    protected override void PluginInitialize()
	{
		Mono.Unix.Catalog.Init("banshee-sendto-plugin", "/usr/share/locale/");			

    }
    private void InstallInterfaceActions()
        {
			Globals.ActionManager.SongActions.Add(new ActionEntry [] {
                new ActionEntry("SendToAction", Stock.Execute,
                    Catalog.GetString("_Send to ..."), null,
                    Catalog.GetString("Send selected song(s) with nautilus send to."), new EventHandler(OnSend))});		
			ui_manager_id=Globals.ActionManager.UI.AddUiFromResource("SendToMenu.xml");
        }
	
    protected override void InterfaceInitialize()
    {
			InstallInterfaceActions();
			InstallInterfaceElements();
    }

	
    protected override void PluginDispose()
    {
		//remove the ui_manager
		Globals.ActionManager.UI.RemoveUi(ui_manager_id);
		//remove the action
		Action sendAction=Globals.ActionManager.FindActionByName("SendToAction");
		Globals.ActionManager.SongActions.Remove(sendAction);
    }
    /* Begin interface initialization */
    private void InstallInterfaceElements()
    {
		current_playlist=(TreeView)InterfaceElements.PlaylistView;				
    }

    /* End interface initialization */


	/* Begin callbacks */
	public void OnSend(object o, EventArgs args) 
    {		
			string param="";
			if (current_playlist.Selection==null)
				return;
			ListStore store=(ListStore)current_playlist.Model;
            foreach(TreePath path in current_playlist.Selection.GetSelectedRows()) 
			{
				TreeIter t;				
				if(!store.GetIter(out t, path))
					continue;
				TrackInfo track=(TrackInfo)store.GetValue(t,0);
				if (track==null)
					continue;
				Console.WriteLine(track.Uri);
				param= param + " " + track.Uri;
			}
			Console.WriteLine("param:"+param);		
			if (param.Equals(""))
			    return;
			Process.Start("nautilus-sendto",param);
    }
    
    /* End callbacks */

    /* Begin properties */
    public bool Enabled {
        get { return enabled; }
        set {
            enabled = value;
			}
    }
}
}
